==> qtjambi-datavisualization-6.5.2-sources.jar: io/qt/datavis/QCategory3DAxis.java <==
package io.qt.datavis;

import io.qt.*;


/**
 * <p>Manipulates an axis of a graph</p>
 * <p>Java wrapper for Qt class <code><a href="https://doc.qt.io/qt/qcategory3daxis.html">QCategory3DAxis</a></code></p>
 */
public class QCategory3DAxis extends io.qt.datavis.QAbstract3DAxis
{
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.@NonNull QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QCategory3DAxis.class);
    

    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qabstract3daxis.html#labels-prop">QAbstract3DAxis::<wbr>labelsChanged()</a></code></p>
     */
    @QtPropertyNotify(name="labels")
    public final @NonNull Signal0 labelsChanged = new Signal0();
    
    /**
     * <p>Overloaded constructor for {@link #QCategory3DAxis(io.qt.core.QObject)}
     *  with <code>parent = null</code>.</p>
     */
    public QCategory3DAxis() {
        this((io.qt.core.QObject)null);
    }
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qcategory3daxis.html#QCategory3DAxis">QCategory3DAxis::<wbr>QCategory3DAxis(QObject*)</a></code></p>
     */
    public QCategory3DAxis(io.qt.core.@Nullable QObject parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QCategory3DAxis instance, io.qt.core.QObject parent);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qabstract3daxis.html#labels-prop">QAbstract3DAxis::<wbr>labels()const</a></code></p>
     */
    @QtPropertyReader(name="labels")
    @QtUninvokable
    public final io.qt.core.@NonNull QStringList labels(){
        return labels_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.core.QStringList labels_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qabstract3daxis.html#labels-prop">QAbstract3DAxis::<wbr>setLabels(QStringList)</a></code></p>
     */
    @QtPropertyWriter(name="labels")
    @QtUninvokable
    public final void setLabels(java.util.@NonNull Collection<java.lang.@NonNull String> labels){
        setLabels_native_cref_QStringList(QtJambi_LibraryUtilities.internal.nativeId(this), labels);
    }
    
    @QtUninvokable
    private native void setLabels_native_cref_QStringList(long __this__nativeId, java.util.Collection<java.lang.String> labels);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     * @hidden
     */
    @NativeAccess
    protected QCategory3DAxis(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * @hidden
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @NativeAccess
    protected QCategory3DAxis(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @QtUninvokable
    private static native void initialize_native(QCategory3DAxis instance, QDeclarativeConstructor constructor);
    
}

==> qtjambi-datavisualization-6.5.7-sources.jar: io/qt/datavis/QCategory3DAxis.java <==
package io.qt.datavis;

import io.qt.*;


/**
 * <p>Manipulates an axis of a graph</p>
 * <p>Java wrapper for Qt class <code><a href="https://doc.qt.io/qt/qcategory3daxis.html">QCategory3DAxis</a></code></p>
 * <p>This class was introduced in Qt QtDataVisualization 1.0.</p>
 */
public class QCategory3DAxis extends io.qt.datavis.QAbstract3DAxis
{
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.@NonNull QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QCategory3DAxis.class);
    

    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qabstract3daxis.html#labels-prop">QAbstract3DAxis::<wbr/>labelsChanged()</a></code></p>
     */
    @QtPropertyNotify(name="labels")
    public final @NonNull Signal0 labelsChanged = new Signal0();
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qcategory3daxis.html#QCategory3DAxis">QCategory3DAxis::<wbr/>QCategory3DAxis(QObject*)</a></code></p>
     */
    public QCategory3DAxis(io.qt.core.@Nullable QObject parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QCategory3DAxis instance, io.qt.core.QObject parent);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qabstract3daxis.html#labels-prop">QAbstract3DAxis::<wbr/>labels()const</a></code></p>
     */
    @QtPropertyReader(name="labels")
    @QtUninvokable
    public final io.qt.core.@NonNull QStringList labels(){
        return labels_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.core.QStringList labels_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qabstract3daxis.html#labels-prop">QAbstract3DAxis::<wbr/>setLabels(QStringList)</a></code></p>
     */
    @QtPropertyWriter(name="labels")
    @QtUninvokable
    public final void setLabels(java.util.@NonNull Collection<java.lang.@NonNull String> labels){
        setLabels_native_cref_QStringList(QtJambi_LibraryUtilities.internal.nativeId(this), labels);
    }
    
    @QtUninvokable
    private native void setLabels_native_cref_QStringList(long __this__nativeId, java.util.Collection<java.lang.String> labels);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     * @hidden
     */
    @NativeAccess
    protected QCategory3DAxis(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     * @hidden
     */
    @NativeAccess
    protected QCategory3DAxis(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @QtUninvokable
    private static native void initialize_native(QCategory3DAxis instance, QDeclarativeConstructor constructor);
    
    
    /**
     * <p>Overloaded constructor for {@link #QCategory3DAxis(io.qt.core.QObject)}
     *  with <code>parent = null</code>.</p>
     */
    public QCategory3DAxis() {
        this((io.qt.core.QObject)null);
    }
}
